@@ -100,7 +100,7 @@ PyGetSetDef firebaseRemoteConfig_getsets[] = {
 
 PyTypeObject FirebaseRemoteConfigType = {
 	PyVarObject_HEAD_INIT(NULL, 0)
-	"igefirebase.remoteConfig",					/* tp_name */
+	"igeFirebase.remoteConfig",					/* tp_name */
 	sizeof(firebaseRemoteConfig_obj),			/* tp_basicsize */
 	0,											/* tp_itemsize */
 	(destructor)firebaseRemoteConfig_dealloc,	/* tp_dealloc */
