@@ -369,14 +369,15 @@ PyDoc_STRVAR(firebaseFirestoreGet_doc,
 PyDoc_STRVAR(firebaseFirestoreSet_doc,
 	"add data to Cloud Firestore\n"\
 	"\n"\
-	"firestore().set(collection, field, value, callback)\n"\
+	"firestore().set(collection, field, value, callback, timestamp)\n"\
 	"\n"\
 	"Parameters\n"\
 	"----------\n"\
 	"    collection : string\n"\
 	"    field : string\n"\
 	"    value : (string, int, double, dictionary)\n"\
-	"    callback : optional function(collection, field, result)");
+	"    callback : optional function(collection, field, result)\n"\
+	"    timestamp : bool(optional)");
 
 //firebase firestore delete
 PyDoc_STRVAR(firebaseFirestoreDelete_doc,
